@@ -15,8 +15,8 @@ class Day_typesQuerySet(BaseRefQuerySet):
 
 class Day_typesManager(BaseRefManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'code': record.code,
