@@ -101,7 +101,7 @@ def get_relation_field_name(model):
     return res
 
 
-def get_dict_only_model_field(data, model, exclude=[]):
+def get_dict_only_model_field(data, model, exclude = []):
     res = dict()
     fields_name = get_fields_name_from_model(model, data)
     for k, v in data.items():
@@ -110,55 +110,9 @@ def get_dict_only_model_field(data, model, exclude=[]):
     return res
 
 
-def check_image_files(apps, schema_editor):
-    from isc_common.models.images import Images
-    from tqdm import tqdm
-    from isc_common.fields.files import make_REPLACE_IMAGE_PATH
-    from django.conf import settings
-    from lfl_admin.common.management.commands import update_img_refs
-    from isc_common.fields.files import FILE_ex
-    import os
-
-    query = Images.objects.exclude().order_by('id')
-    pbar = tqdm(total=query.count())
-    ssh_files = settings.SSH_CLIENTS.client(settings.FILES_STORE)
-    o_ssh_files = settings.SSH_CLIENTS.client( settings.OLD_FILES )
-
-    for image in query:
-
-        image_fullpath = make_REPLACE_IMAGE_PATH(image.real_name)
-        deleted = False
-        if o_ssh_files.exists(image_fullpath) is False:
-            logger.debug(f'Deliting : {image}')
-            try:
-                if FILE_ex(image=image, ssh_files=ssh_files)[0] is False:
-                    image.delete()
-                    deleted = True
-            except Exception as ex:
-                deleted = True
-                image.file_name = None
-                image.size = 0
-                image.attfile = ''
-                image.save()
-                logger.error(ex)
-
-        if deleted is False:
-            exists, size = FILE_ex(image=image, ssh_files=ssh_files)
-            if exists is True:
-                _, file_name = os.path.split(image_fullpath)
-                imagen = Images.objects.exclude(id=image.id).getOptional(file_name=file_name, size=size)
-
-                if imagen is not None:
-                    update_img_refs(old_id=imagen.id, new_id=image.id)
-                image.file_name = file_name
-                image.size = size
-                image.save()
-
-            else:
-                image.file_name = None
-                image.size = 0
-                image.attfile = ''
-                image.save()
-
-        pbar.update()
-    logger.info('Done.')
+def update_dict(indict, updater_dict):
+    if isinstance(indict, dict) and isinstance(updater_dict, dict):
+        indict.update(updater_dict)
+        return indict
+    else:
+        return indict
