@@ -87,7 +87,7 @@ class Model_images(AuditModel):
     @classmethod
     def update_or_create_image(cls, main_model, path, file_name, keyimage, self_image_field=False, code=None, exception=True, defaults=None, o_ssh_client=None):
         from isc_common.models.images import Images
-        from lfl_admin.common.models.site_lfl_images import Site_lfl_images
+        # from lfl_admin.common.models.site_lfl_images import Site_lfl_images
 
         result = Stack()
 
@@ -98,7 +98,8 @@ class Model_images(AuditModel):
             code = path
 
         with transaction.atomic():
-            full_name_images = Site_lfl_images.get_image(file_name=file_name, path=path)
+            # full_name_images = Site_lfl_images.get_image(file_name=file_name, path=path)
+            full_name_images = []
 
             if len(full_name_images) == 0 and file_name is not None:
                 if exception is True:
