@@ -1,11 +1,13 @@
 import logging
 
 from bitfield import BitField
+
 from isc_common.auth.models.user import User
-from isc_common.fields.related import ForeignKeyProtect
+from isc_common.fields.related import ForeignKeyProtect , ForeignKeyCascade
 from isc_common.models.audit import Model_withOldIds
+from isc_common.models.image_types import Image_types
 from isc_common.models.images import Images
-from isc_common.models.model_images import Model_imagesQuerySet, Model_images, Model_imagesManager
+from isc_common.models.model_images import Model_imagesQuerySet , Model_images , Model_imagesManager
 
 logger = logging.getLogger(__name__)
 
@@ -22,8 +24,8 @@ class Users_imagesManager(Model_imagesManager):
             ('main_photo', 'main_photo'),  # 1
         ), default=0, db_index=True)
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record ) :
         res = {
             'id': record.id,
             'editing': record.editing,
@@ -37,8 +39,9 @@ class Users_imagesManager(Model_imagesManager):
 
 class Users_images(Model_images, Model_withOldIds):
     image = ForeignKeyProtect(Images)
-    main_model = ForeignKeyProtect(User)
+    main_model = ForeignKeyCascade(User)
     props = Users_imagesManager.props()
+    type = ForeignKeyProtect(Image_types)
 
     objects = Users_imagesManager()
 
@@ -50,4 +53,4 @@ class Users_images(Model_images, Model_withOldIds):
 
     class Meta:
         verbose_name = 'Кросс таблица'
-        unique_together = (('image', 'main_model', 'props'),)
+        unique_together = (('image', 'main_model', 'props', 'type', 'deleted_at'),)
